=================================
Scheme Editor (:mod:`schemeedit`)
=================================

.. automodule:: orangecanvas.document.schemeedit


.. autoclass:: SchemeEditWidget
   :members:
   :exclude-members:
      undoAvaliable,
      redoAvaliable,
      modificationChanged,
      undoCommandAdded,
      selectionChanged,
      titleChanged,
      pathChanged,
      onNewLink
   :member-order: bysource
   :show-inheritance:

   .. automethod:: undoAvailable(bool)

   .. automethod:: redoAvailable(bool)

   .. automethod:: modificationChanged(bool)

   .. automethod:: undoCommandAdded()

   .. automethod:: selectionChanged()

   .. automethod:: titleChanged()

   .. automethod:: pathChanged()
